import { fileExists } from "lib/fileExists";
import { Answer } from "types/Answer";
import { nil } from "types/Nil";
const execa = require('execa'); // fancy child_process
const Listr = require('listr'); // fancy CLI todo list

function checkSubmodules() {
	return execa.stdout('cat', [ '.gitmodules' ])
		.then(data => {

			let submodules = data.split("\n")
				.filter( line => /path = /.test(line.trim()) )
				.map( line => line.trim().replace(/^path = /, '') );

			let tasks = submodules.map (
				submodule => {
					return {
						title: submodule,
						task(ctx, task) {
							return new Promise((done, fail) => {
								fileExists((err, answer) => {
									if (err == nil) {
										if (answer == Answer.Yes) {
											done(true);
										}
										else { // fail
											fail(new Error(`${submodule} not initalized`));
										}
									}
									else { // failure
										fail(err);
									}
								}, `${submodule}/.git`)
							});
						}
					};
				}
			);

			return new Listr(tasks, { concurrent: true, exitOnError: false });
		})
}

module.exports = {
	title: 'verify submodule status',
	task: checkSubmodules
}