import { each } from "lib/each";
import { fileExists } from "lib/fileExists";
import { Answer } from "types/Answer";
const fs = require('fs');

module.exports = {
	title: 'deps installed',
	task() {

		let pkg = JSON.parse(fs.readFileSync('package.json').toString());

		let promises: any[] = [];

		promises.push (
			new Promise((done, fail) => {
				fileExists((err, answer) => {
					if (answer == Answer.Yes) {
						done();
					}
					else {
						fail(new Error(`NPM modules not installed`));
					}
				}, `node_modules`)
			})
		);

		promises.push (
			new Promise((done, fail) => {
				fileExists((err, answer) => {
					if (answer == Answer.Yes) {
						done();
					}
					else {
						fail(new Error(`Missing yarn.lock file`));
					}
				}, `yarn.lock`)
			})
		);

		each(pkg.dependencies, (version, moduleName) => {
			promises.push (
				new Promise((done, fail) => {
					fileExists((err, answer) => {
						if (answer == Answer.Yes) {
							done();
						}
						else {
							fail(new Error(`Missing ${moduleName}`));
						}
					}, `node_modules/${moduleName}`)
				})
			);
		});

		each(pkg.devDependencies, (version, moduleName) => {
			promises.push (
				new Promise((done, fail) => {
					fileExists((err, answer) => {
						if (answer == Answer.Yes) {
							done();
						}
						else {
							fail(new Error(`Missing ${moduleName}`));
						}
					}, `node_modules/${moduleName}`)
				})
			);
		});

		return Promise.all(promises);
	}
};