import { each } from "lib/each";
import { fileExists } from "lib/fileExists";
import { Answer } from "types/Answer";
const fs = require('fs');

module.exports = {
	title: 'deps installed',
	task(ctx, task) {

		let pkg = JSON.parse(fs.readFileSync('composer.json').toString());

		let promises: any[] = [];

		const vendorDir = pkg.config && pkg.config['vendor-dir'] ? pkg.config['vendor-dir'] : 'vendor';

		promises.push (
			new Promise((done, fail) => {
				fileExists((err, answer) => {
					if (answer == Answer.Yes) {
						done();
					}
					else {
						fail(new Error(`NPM modules not installed`));
					}
				}, vendorDir)
			})
		);

		promises.push (
			new Promise((done, fail) => {
				fileExists((err, answer) => {
					if (answer == Answer.Yes) {
						done();
					}
					else {
						fail(new Error(`Missing composer.lock file`));
					}
				}, `composer.lock`)
			})
		);

		each(pkg.require, (version, moduleName) => {
			if (moduleName != 'php') {
				promises.push (
					new Promise((done, fail) => {
						fileExists((err, answer) => {
							if (answer == Answer.Yes) {
								done();
							}
							else {
								fail(new Error(`Missing ${moduleName}`));
							}
						}, `${vendorDir}/${moduleName}`)
					})
				);
			}
		});

		return Promise.all(promises);
	}
};